Crate prosa_hyper

Crate prosa_hyper 

© 2024 Worldline SA, All rights reserved

githubcrates-iodocs-rs

ProSA Hyper processor to handle HTTP client and server

Modules

client
Module to handle HTTP client
server
Module to handle HTTP server

Enums

HttpError
Error related to an HTTP message or Hyper error
HyperProcError
Global Hyper processor error
HyperResp
Enum to define all type of response to request it can be made

Constants

PRODUCT_VERSION_HEADER
Product version header value used for Server or User-Agent header in HTTP requests and responses

Type Aliases

SrvRespHandler
Type alias for the closure that processes an internal service response or error.