HyperResp

Enum HyperResp 

pub enum HyperResp<A, M>
where A: HyperServerAdaptor<M>, M: 'static + Send + Sync + Sized + Clone + Debug + Tvf + Default,
{ SrvReq(String, M, SrvRespHandler<A, M>), HttpResp(Response<BoxBody<Bytes, Infallible>>), HttpErr(HttpError), }
Enum to define all type of response to request it can be made

Variants



SrvReq(String, M, SrvRespHandler<A, M>)

Make an internal service request and process the response with the provided handler



HttpResp(Response<BoxBody<Bytes, Infallible>>)

Make a direct HTTP response



HttpErr(HttpError)

Response with an HTTP error