Module adaptor

Module adaptor 

Adaptor for Hyper server processor Hyper server adaptor definition

Structs

HelloHyperServerAdaptor
Hello adaptor for the Hyper server processor. Use to respond to a request with a simple hello message

Traits

HyperServerAdaptor
Trait to define the Hyper server adaptor structure

Functions

default_srv_error_response
Convert a service error message into a default HTTP response.