Modules
Enums
- Http
Error - Error related to an HTTP message or Hyper error
- Hyper
Proc Error - Global Hyper processor error
- Hyper
Resp - Enum to define all type of response to request it can be made
Constants
- PRODUCT_
VERSION_ HEADER - Product version header value used for
ServerorUser-Agentheader in HTTP requests and responses
Type Aliases
- SrvResp
Handler - Type alias for the closure that processes an internal service response or error.