Adaptor for Hyper server processor Hyper server adaptor definition
Structs
- Hello
Hyper Server Adaptor - Hello adaptor for the Hyper server processor. Use to respond to a request with a simple hello message
Traits
- Hyper
Server Adaptor - Trait to define the Hyper server adaptor structure
Functions
- default_
srv_ error_ response - Convert a service error message into a default HTTP response.